using System;
using System.Data;
using System.Data.SqlClient;
using System.IO;

namespace NantSample {

	public class MessageServer {

		// connstructor
		public MessageServer() { }

		// get message, using specified config dir
		public string GetMessage(string configdir) {
			string connstr = GetConnectionString(configdir);
			return GetMessageFromDatabase(connstr);
		}

		// get message, using default config dir (working dir)
		public string GetMessage() {
			return GetMessage(System.Environment.CurrentDirectory);
		}

		// get connection string
		private string GetConnectionString(string configdir) {
			string connstr;
			string path = Path.Combine(configdir, "ConnectionString");
      try {
        using (StreamReader file = new StreamReader(path)) {
          connstr = file.ReadLine();
          file.Close();
        }
      }
      catch (Exception ex) {
        throw new ApplicationException("Error reading connection string: " + ex.Message, ex);
      }
			return connstr;
		}

		// get message from database
		private string GetMessageFromDatabase(string connstr) {
      string msg;
			using (SqlConnection conn = new SqlConnection(connstr)) {
        try {
          conn.Open();
        } catch (Exception ex) {
          throw new ApplicationException("Error connecting to database: " + ex.Message, ex);
        }
        using (SqlCommand cmd = new SqlCommand("p_GetMessage", conn)) {
          try {
            msg = cmd.ExecuteScalar().ToString();
          } catch (Exception ex) {
            conn.Close();
            throw new ApplicationException("Error querying database: " + ex.Message, ex);
          }
        }
        conn.Close();
      }
      return msg;
		}
	}
}
